﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using Sample.Models;
using Syncfusion.OfficeChart;
using Syncfusion.DocIO;
using Syncfusion.DocIORenderer;
using Syncfusion.Pdf;
using Syncfusion.DocIO.DLS;
using System.Threading;

namespace Sample.Controllers
{
    public class HomeController : Controller
    {
        public IActionResult Index()
        {
            return View();
        }

        private readonly IHostingEnvironment _hostingEnvironment;

        public HomeController(IHostingEnvironment hostingEnvironment)
        {
            _hostingEnvironment = hostingEnvironment;
        }

        [HttpPost]

        public void ConvertToPDF()
        {
            //Get the file path of the Word document
            string inputFilePath = _hostingEnvironment.WebRootPath + @"\WordtoPDF.docx";
            try
            {
                //Set the generated output path with file name
                string outputFileName = _hostingEnvironment.WebRootPath + @"\Output.pdf";
                //Create a new instance of Word application
                Microsoft.Office.Interop.Word.Application wordApp = new Microsoft.Office.Interop.Word.Application(); 
                //open the existing Word document from the specified path
                Microsoft.Office.Interop.Word.Document doc = wordApp.Documents.Open(inputFilePath, false);
                doc.Activate();
                //Conver the Word document to PDF
                doc.SaveAs2(outputFileName, Microsoft.Office.Interop.Word.WdSaveFormat.wdFormatPDF);
                //Close the instance of word application
                doc.Close(false);
                System.Runtime.InteropServices.Marshal.ReleaseComObject(doc);
            }
            catch (Exception ex)
            {
                //Open the file as Stream
                FileStream docStream = new FileStream(inputFilePath, FileMode.Open, FileAccess.Read);
                //Loads file stream into Word document
                WordDocument wordDocument = new WordDocument(docStream, Syncfusion.DocIO.FormatType.Automatic);
                //Instantiation of DocIORenderer for Word to PDF conversion
                DocIORenderer render = new DocIORenderer();
                //Sets Chart rendering Options.
                render.Settings.ChartRenderingOptions.ImageFormat = ExportImageFormat.Jpeg;
                //Converts Word document into PDF document
                PdfDocument pdfDocument = render.ConvertToPDF(wordDocument);
                //Releases all resources used by the Word document and DocIO Renderer objects
                render.Dispose();
                wordDocument.Dispose();
                FileStream fileStream = new FileStream(_hostingEnvironment.WebRootPath + @"\Syncfusion_Output.pdf", FileMode.Create);
                pdfDocument.Save(fileStream);
                fileStream.Position = 0;
                //Closes the instance of PDF document object
                pdfDocument.Close();
            }
        }

        public IActionResult About()
        {
            ViewData["Message"] = "Your application description page.";

            return View();
        }

        public IActionResult Contact()
        {
            ViewData["Message"] = "Your contact page.";

            return View();
        }

        public IActionResult Error()
        {
            return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
        }
    }
}
